@@ -64,7 +64,7 @@ IconMode::IconMode( QObject *parent, const QVariantList& )
     d->aboutIcon->setProgramIconName( "view-list-icons" );
 
     d->backAction = KStandardAction::back( this, SLOT(backToOverview()), this );
-    d->backAction->setText( i18n( "Overview" ) );
+    d->backAction->setText( i18n( "All Settings" ) );
     d->backAction->setToolTip( i18n("Keyboard Shortcut: %1", d->backAction->shortcut().toString( QKeySequence::NativeText )) );
     d->backAction->setEnabled( false );
     actionsList() << d->backAction;
@@ -114,8 +114,8 @@ void IconMode::initEvent()
 
     d->mainWidget = new QStackedWidget();
     d->moduleView = new ModuleView( d->mainWidget );
-    connect( d->moduleView, SIGNAL(moduleChanged(bool)), this, SLOT(moduleLoaded()) );
-    connect( d->moduleView, SIGNAL(closeRequest()), this, SLOT(backToOverview()) );
+    connect( d->moduleView, &ModuleView::moduleChanged, this, &IconMode::moduleLoaded );
+    connect( d->moduleView, &ModuleView::closeRequest, this, &IconMode::backToOverview );
     d->categoryView = 0;
 }
 
@@ -179,8 +179,8 @@ void IconMode::initWidget()
 
     d->categoryView->setFrameShape( QFrame::NoFrame );
     d->categoryView->setModel( d->proxyModel );
-    connect( d->categoryView, SIGNAL(activated(QModelIndex)),
-             this, SLOT(changeModule(QModelIndex)) );
+    connect( d->categoryView, &QAbstractItemView::activated,
+             this, &IconMode::changeModule );
 
     d->mainWidget->addWidget( d->categoryView );
     d->mainWidget->addWidget( d->moduleView );
